Dummy Module
============

.. autoclass:: dummy_module.Class
   :members:
   :undoc-members:
   :private-members:
   :special-members: __magic_custom_method__

.. autoexception:: dummy_module.DummyException
   :members:
   :undoc-members:

.. autofunction:: dummy_module.function
